@@ -50,11 +50,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <General_utils.h>
 #include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
 #include "questions.h"
 #include "Coordinate_systems.h"
 #include "variogramAndCo.h"
 #include "Processes.h"
 #include "rf_interfaces.h"
+extern const char *general[generalN];
+
 
 /* 
  in CheckCovariance and other the following dimensions are used:
